@@ -165,8 +165,12 @@ class SSHClient(object):
                 exit_status = stdout.channel.recv_exit_status()
                 std_output = stdout.read().decode()
                 std_err = stderr.read().decode()
-                log.info(
-                    f" {self.__ip}:{self.__port} | successful to run cmd {cmd}, output is:{std_output} and stderr:{std_err}.")
+                if not std_err:
+                    log.info(
+                        f" {self.__ip}:{self.__port} | successful to run cmd {cmd}, exit_status_code is {exit_status}, output is:{std_output} and stderr:{std_err}.")
+                else:
+                    log.info(
+                    f" {self.__ip}:{self.__port} | successful to run cmd {cmd}, exit_status_code is {exit_status}, output is:{std_output}.")
                 return ExecResult(exit_status, std_output, std_err)
         except Exception as e:
             return ExecResult(1, "", str(e))
